summaryrefslogtreecommitdiffstats
path: root/klipper
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:29:23 -0600
commit628043be55ddd2f534411d028e4f68c8fe4eaabb (patch)
tree29459652112ab6d5dfbf27ac0bbf5b86b7c83bca /klipper
parent2c01fd64ddde84a6d78b632f7f3b7c3560dc288c (diff)
downloadtdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.tar.gz
tdebase-628043be55ddd2f534411d028e4f68c8fe4eaabb.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'klipper')
-rw-r--r--klipper/applet.cpp2
-rw-r--r--klipper/configdialog.cpp10
-rw-r--r--klipper/configdialog.h8
-rw-r--r--klipper/historyitem.cpp2
-rw-r--r--klipper/popupproxy.cpp2
-rw-r--r--klipper/toplevel.cpp14
-rw-r--r--klipper/urlgrabber.h2
7 files changed, 20 insertions, 20 deletions
diff --git a/klipper/applet.cpp b/klipper/applet.cpp
index 24b5b6a34..97eee6eec 100644
--- a/klipper/applet.cpp
+++ b/klipper/applet.cpp
@@ -91,7 +91,7 @@ void KlipperApplet::preferences()
void KlipperApplet::help()
{
- kapp->invokeHelp(TQString::null, TQString::tqfromLatin1("klipper"));
+ kapp->invokeHelp(TQString::null, TQString::fromLatin1("klipper"));
}
void KlipperApplet::about()
diff --git a/klipper/configdialog.cpp b/klipper/configdialog.cpp
index ea1fb0974..7428a4ed3 100644
--- a/klipper/configdialog.cpp
+++ b/klipper/configdialog.cpp
@@ -66,7 +66,7 @@ void ConfigDialog::show()
{
if ( !isVisible() ) {
KWinModule module(0, KWinModule::INFO_DESKTOP);
- TQSize s1 = tqsizeHint();
+ TQSize s1 = sizeHint();
TQSize s2 = module.workArea().size();
int w = s1.width();
int h = s1.height();
@@ -299,13 +299,13 @@ ActionWidget::ActionWidget( const ActionList *list, ConfigDialog* configWidget,
connect( delActionButton, TQT_SIGNAL( clicked() ), TQT_SLOT( slotDeleteAction() ));
TQLabel *label = new TQLabel(i18n("Click on a highlighted item's column to change it. \"%s\" in a command will be replaced with the clipboard contents."), box);
- label->tqsetAlignment( WordBreak | AlignLeft | AlignVCenter );
+ label->setAlignment( WordBreak | AlignLeft | AlignVCenter );
box->setStretchFactor( label, 5 );
box = new TQHBox( this );
TQPushButton *advanced = new TQPushButton( i18n("Advanced..."), box );
- advanced->setFixedSize( advanced->tqsizeHint() );
+ advanced->setFixedSize( advanced->sizeHint() );
connect( advanced, TQT_SIGNAL( clicked() ), TQT_SLOT( slotAdvanced() ));
(void) new TQWidget( box ); // spacer
@@ -410,8 +410,8 @@ void ActionWidget::slotAdvanced()
AdvancedWidget *widget = new AdvancedWidget( box );
widget->setWMClasses( m_wmClasses );
- dlg.resize( dlg.tqsizeHint().width(),
- dlg.tqsizeHint().height() +40); // or we get an ugly scrollbar :(
+ dlg.resize( dlg.sizeHint().width(),
+ dlg.sizeHint().height() +40); // or we get an ugly scrollbar :(
if ( dlg.exec() == TQDialog::Accepted ) {
m_wmClasses = widget->wmClasses();
diff --git a/klipper/historyitem.cpp b/klipper/historyitem.cpp
index 3dfc37f17..86c19f07a 100644
--- a/klipper/historyitem.cpp
+++ b/klipper/historyitem.cpp
@@ -52,7 +52,7 @@ HistoryItem* HistoryItem::create( const TQMimeSource& aSource )
TQMap<TQString,TQString> metaData;
if( KURLDrag::decode( &aSource, urls, metaData )) {
// this is from KonqDrag (libkonq)
- TQByteArray a = aSource.tqencodedData( "application/x-kde-cutselection" );
+ TQByteArray a = aSource.encodedData( "application/x-kde-cutselection" );
bool cut = !a.isEmpty() && (a.tqat(0) == '1'); // true if 1
return new HistoryURLItem( urls, metaData, cut );
}
diff --git a/klipper/popupproxy.cpp b/klipper/popupproxy.cpp
index cff763ff6..838888bb9 100644
--- a/klipper/popupproxy.cpp
+++ b/klipper/popupproxy.cpp
@@ -133,7 +133,7 @@ int PopupProxy::insertFromSpill( int index ) {
// discarding any that doesn't match the current filter.
// stop when the total number of items equal m_itemsPerMenu;
int count = 0;
- int remainingHeight = m_menu_height - proxy_for_menu->tqsizeHint().height();
+ int remainingHeight = m_menu_height - proxy_for_menu->sizeHint().height();
// Force at least one item to be inserted.
remainingHeight = QMAX( remainingHeight, 0 );
for ( const HistoryItem* item = spillPointer.current();
diff --git a/klipper/toplevel.cpp b/klipper/toplevel.cpp
index 81c7bd326..4b1afb572 100644
--- a/klipper/toplevel.cpp
+++ b/klipper/toplevel.cpp
@@ -327,7 +327,7 @@ void KlipperWidget::showPopupMenu( TQPopupMenu *menu )
{
Q_ASSERT( menu != 0L );
- TQSize size = menu->tqsizeHint(); // geometry is not valid until it's shown
+ TQSize size = menu->sizeHint(); // geometry is not valid until it's shown
if (bPopupAtMouse) {
TQPoint g = TQCursor::pos();
if ( size.height() < g.y() )
@@ -1013,13 +1013,13 @@ TQString KlipperWidget::getClipboardHistoryItem(int i)
//
bool KlipperWidget::ignoreClipboardChanges() const
{
- TQWidget *tqfocusWidget = tqApp->tqfocusWidget();
- if ( tqfocusWidget )
+ TQWidget *focusWidget = tqApp->focusWidget();
+ if ( focusWidget )
{
- if ( tqfocusWidget->inherits( TQSPINBOX_OBJECT_NAME_STRING ) ||
- (tqfocusWidget->parentWidget() &&
- tqfocusWidget->inherits(TQLINEEDIT_OBJECT_NAME_STRING) &&
- tqfocusWidget->parentWidget()->inherits(TQSPINWIDGET_OBJECT_NAME_STRING)) )
+ if ( focusWidget->inherits( TQSPINBOX_OBJECT_NAME_STRING ) ||
+ (focusWidget->parentWidget() &&
+ focusWidget->inherits(TQLINEEDIT_OBJECT_NAME_STRING) &&
+ focusWidget->parentWidget()->inherits(TQSPINWIDGET_OBJECT_NAME_STRING)) )
{
return true;
}
diff --git a/klipper/urlgrabber.h b/klipper/urlgrabber.h
index 40d288b9a..b5212890b 100644
--- a/klipper/urlgrabber.h
+++ b/klipper/urlgrabber.h
@@ -132,7 +132,7 @@ public:
inline bool matches( const TQString& string ) {
int res = myRegExp.search( string ) ;
if ( res != -1 ) {
- myCapturedTexts = myRegExp.tqcapturedTexts();
+ myCapturedTexts = myRegExp.capturedTexts();
return true;
}
return false;
diff --git a/klipper/configdialog.h b/klipper/configdialog.h
index 219f5f6cf..514f40bc7 100644
--- a/klipper/configdialog.h
+++ b/klipper/configdialog.h
@@ -237,11 +237,11 @@ public:
ListView( ConfigDialog* configWidget, TQWidget *parent, const char *name )
: KListView( parent, name ), _configWidget( configWidget ),
_regExpEditor(0L) {}
- // TQListView has a weird idea of a tqsizeHint...
- virtual TQSize tqsizeHint () const {
- int w = tqminimumSizeHint().width();
+ // TQListView has a weird idea of a sizeHint...
+ virtual TQSize sizeHint () const {
+ int w = minimumSizeHint().width();
int h = header()->height();
- h += viewport()->tqsizeHint().height();
+ h += viewport()->sizeHint().height();
h += horizontalScrollBar()->height();
TQListViewItem *item = firstChild();